Note: This is package is incomplete and still in initial development phase. The API may change without deprecation.

Requires Python 3.10+.

See also:

* https://github.com/5j9/tsetmc


If you are interested in other information that are available on fipiran.com but this library has no API for, please `open an issue`_ for them on github.


.. _open an issue: https://github.com/5j9/fipiran/issues
